@@ -6,9 +6,9 @@
 #
 
 import os
-import subprocess
 
 from photofilmstrip.action.IAction import IAction
+from photofilmstrip.lib.util import StartFile
 
 
 class ActionOpenFolder(IAction):
@@ -19,16 +19,9 @@ class ActionOpenFolder(IAction):
     def GetName(self):
         return _("Open folder")
 
-    def GetBitmap(self):
-        import wx
-        return wx.ArtProvider.GetBitmap('PFS_FOLDER_OPEN_16')
-
     def Execute(self):
         outDir = os.path.dirname(self.outFile)
         if not os.path.isdir(outDir):
             return
 
-        if os.name == "nt":
-            os.startfile(outDir)  # pylint: disable=no-member
-        else:
-            subprocess.Popen(["xdg-open", outDir])
+        StartFile(outDir)
