@@ -1,23 +1,9 @@
-# encoding: UTF-8
+# -*- coding: utf-8 -*-
 #
 # PhotoFilmStrip - Creates movies out of your pictures.
 #
 # Copyright (C) 2011 Jens Goepfert
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
 
 import logging
 import os
@@ -26,11 +12,12 @@ from photofilmstrip.action.IAction import IAction
 
 from photofilmstrip.lib.Settings import Settings
 from photofilmstrip.lib.util import CheckFile
-from photofilmstrip.core.Renderer import RENDERERS
+from photofilmstrip.core.Renderers import RENDERERS
 from photofilmstrip.core.RenderEngine import RenderEngineSlideshow, \
     RenderEngineTimelapse
 from photofilmstrip.core.RenderJob import RenderJob
 from photofilmstrip.core.GPlayer import GPlayer
+from photofilmstrip.core.exceptions import RenderException
 
 
 class ActionRender(IAction):
@@ -48,7 +35,7 @@ class ActionRender(IAction):
         self.__renderJob = None
 
     def GetName(self):
-        return _(u'Start')
+        return _("Start")
 
     def _CheckAndGetOutFile(self):
         if self.__outpath == "-":
@@ -68,21 +55,35 @@ class ActionRender(IAction):
         settings = Settings()
         settings.SetLastProfile(self.__profile.GetName())
 
-        idxRenderer = RENDERERS.index(self.__rendererClass)
+        try:
+            idxRenderer = RENDERERS.index(self.__rendererClass)
+        except ValueError:
+            return
+
         settings.SetUsedRenderer(idxRenderer)
 
     def Execute(self):
         audioFiles = []
+        invalidAudioFiles = []
         audioLength = 0
         for audioFile in self.__photoFilmStrip.GetAudioFiles():
             if CheckFile(audioFile):
                 length = GPlayer(audioFile).GetLength()
-                audioFiles.append(audioFile)
-                logging.debug("Using audiofile '%s' with length: %s", audioFile, length)
-                audioLength += length
+                if length is None:
+                    logging.warning("Invalid audiofile '%s'", audioFile)
+                    invalidAudioFiles.append(audioFile)
+                else:
+                    audioFiles.append(audioFile)
+                    logging.debug("Using audiofile '%s' with length: %s", audioFile, length)
+                    audioLength += length
             else:
                 logging.warning("Missing audiofile '%s'!", audioFile)
 
+        if len(audioFiles) != len(self.__photoFilmStrip.GetAudioFiles()):
+            raise RenderException(
+                _("The following audio files are invalid or missing:") + "\n\n" + "\n".join(
+                    invalidAudioFiles))
+
         outFile = self._CheckAndGetOutFile()
 
         self._SaveSettings()
@@ -104,10 +105,12 @@ class ActionRender(IAction):
         renderer.SetAudioFiles(audioFiles)
 
         if self.__photoFilmStrip.GetTimelapse():
+            uxEvent = "RenderTimeLapse"
             renderEngine = RenderEngineTimelapse(self.__profile,
                                                  self.__photoFilmStrip.GetPictures(),
                                                  self.__draftMode)
         else:
+            uxEvent = "RenderSlideshow"
             renderEngine = RenderEngineSlideshow(self.__profile,
                                                  self.__photoFilmStrip.GetPictures(),
                                                  self.__draftMode,
@@ -118,6 +121,8 @@ class ActionRender(IAction):
 
         self.__renderJob = RenderJob(name, renderer,
                                      renderEngine.GetTasks())
+        self.__renderJob.AddUxEvent(uxEvent)
+        self.__renderJob.AddUxEvent(self.__profile.GetName())
 
     def GetRenderJob(self):
         return self.__renderJob
