@@ -25,7 +25,7 @@ class Project(Observable):
 
     def GetName(self):
         if self.__filename is None:
-            return u""
+            return ""
         fname = os.path.splitext(self.__filename)[0]
         return os.path.basename(fname)
 
@@ -46,8 +46,10 @@ class Project(Observable):
             self.Notify("duration")
 
     def SetAudioFiles(self, audioFiles):
+        oldAudioFiles = self.__audioFiles
         self.__audioFiles = audioFiles
-        self.Notify("audiofile")
+        if self.__audioFiles != oldAudioFiles:
+            self.Notify("audiofile")
 
     def GetAudioFile(self):
         '''
