@@ -14,13 +14,15 @@ from photofilmstrip.lib.common.ObserverPattern import Observer
 from photofilmstrip.lib.Settings import Settings
 from photofilmstrip.lib.jobimpl.JobManager import JobManager
 from photofilmstrip.lib.jobimpl.VisualJob import VisualJob
+from photofilmstrip.lib.util import StartFile
 
 from photofilmstrip.core.Aspect import Aspect
-from photofilmstrip.core.Media import Media, MediaOrientation
+from photofilmstrip.core.Media import Media, MediaOrientation, MediaAudioLevel
 from photofilmstrip.core.OutputProfile import OutputProfile, FPS25
 from photofilmstrip.core.StoryFile import StoryFile
 from photofilmstrip.core.StoryEngine import StoryEngine
 
+from photofilmstrip.gui.Art import Art
 from photofilmstrip.gui.ctrls.PnlNotification import PnlNotification
 from photofilmstrip.gui.DlgRender import DlgRender, FormatData
 from photofilmstrip.gui.PnlEditorPage import PnlEditorPage
@@ -42,7 +44,6 @@ class PnlStory(PnlEditorPage, Observer):
 
     def __init__(self, parent, story):
         PnlEditorPage.__init__(self, parent)
-        Observer.__init__(self)
         self.__story = story
 
         self.splitWin = wx.SplitterWindow(self)
@@ -50,6 +51,7 @@ class PnlStory(PnlEditorPage, Observer):
         self.pnlMedias = PnlMediaContainer(self.splitWin)
         self.pnlMedias.SetupScrolling(scroll_x=False)
         self.pnlMedias.Bind(wx.EVT_CHAR_HOOK, self._OnKeyDown)
+        self.pnlMedias.Bind(wx.EVT_LIST_ITEM_ACTIVATED, self._OnActivateMedia)
 
         self.treeCtrlr = TreeController(story, self.pnlMedias, self)
 
@@ -202,6 +204,12 @@ class PnlStory(PnlEditorPage, Observer):
             wxvJob.GetOutputFile = lambda: outpath
         JobManager().EnqueueContext(wxvJob)
 
+    def _OnActivateMedia(self, event):
+        selItm = self.treeCtrlr.GetSelectedItem()
+        if selItm.IsOk():
+            media = selItm.data
+            StartFile(media.GetFilename())
+
     def GetProject(self):
         return self.__story
 
@@ -262,53 +270,51 @@ class PnlStory(PnlEditorPage, Observer):
         return ".pfstory"
 
     def AddMenuEditActions(self, menu):
-        menuSize = wx.ArtProvider.GetSizeHint(wx.ART_MENU)
         CreateMenuItem(menu, ID_MEDIA_ADD,
                        _("Add media") + "\tCtrl+I",
-                       wx.ArtProvider.GetBitmap('PFS_IMPORT_PICTURES_16'),
-                       wx.ArtProvider.GetBitmap('PFS_IMPORT_PICTURES_D_16'))
+                       Art.GetBitmapBundle('PFS_IMPORT_PICTURES', wx.ART_MENU),
+                       Art.GetBitmapBundle('PFS_IMPORT_PICTURES_D', wx.ART_MENU))
         menu.AppendSeparator()
         CreateMenuItem(menu, ID_MEDIA_MOVE_UP,
                        _("Move up"),
-                       wx.ArtProvider.GetBitmap(wx.ART_GO_UP, wx.ART_MENU, menuSize))
+                       Art.GetBitmapBundle(wx.ART_GO_UP, wx.ART_MENU))  # TODO: PFS_ART
         CreateMenuItem(menu, ID_MEDIA_MOVE_DOWN,
                        _("Move down"),
-                       wx.ArtProvider.GetBitmap(wx.ART_GO_DOWN, wx.ART_MENU, menuSize))
+                       Art.GetBitmapBundle(wx.ART_GO_DOWN, wx.ART_MENU))  # TODO: PFS_ART
         CreateMenuItem(menu, ID_MEDIA_REMOVE,
                        _("Remove") + "\tCtrl+Del",
-                       wx.ArtProvider.GetBitmap(wx.ART_DELETE, wx.ART_MENU, menuSize))
+                       Art.GetBitmapBundle(wx.ART_DELETE, wx.ART_MENU))  # TODO: PFS_ART
 
     def AddToolBarActions(self, toolBar):
-        toolSize = wx.ArtProvider.GetSizeHint(wx.ART_TOOLBAR)
         toolBar.AddTool(ID_MEDIA_ADD, "",
-                        wx.ArtProvider.GetBitmap('PFS_IMPORT_PICTURES_24'),
-                        wx.ArtProvider.GetBitmap('PFS_IMPORT_PICTURES_D_24'),
+                        Art.GetBitmapBundle('PFS_IMPORT_PICTURES', wx.ART_TOOLBAR),
+                        Art.GetBitmapBundle('PFS_IMPORT_PICTURES_D', wx.ART_TOOLBAR),
                         wx.ITEM_NORMAL,
                         _("Add media"), _("Add clip"))
         toolBar.AddSeparator()
         toolBar.AddTool(ID_MEDIA_MOVE_UP, "",
-                        wx.ArtProvider.GetBitmap(wx.ART_GO_UP, wx.ART_TOOLBAR, toolSize),
+                        Art.GetBitmapBundle(wx.ART_GO_UP, wx.ART_TOOLBAR),  # TODO: PFS_ART
                         shortHelp=_("Move up"))
         toolBar.AddTool(ID_MEDIA_MOVE_DOWN, "",
-                        wx.ArtProvider.GetBitmap(wx.ART_GO_DOWN, wx.ART_TOOLBAR, toolSize),
+                        Art.GetBitmapBundle(wx.ART_GO_DOWN, wx.ART_TOOLBAR),  # TODO: PFS_ART
                         shortHelp=_("Move down"))
         toolBar.AddTool(ID_MEDIA_MOVE_OUT, "",
-                        wx.ArtProvider.GetBitmap(wx.ART_GO_BACK, wx.ART_TOOLBAR, toolSize),
+                        Art.GetBitmapBundle(wx.ART_GO_BACK, wx.ART_TOOLBAR),  # TODO: PFS_ART
                         shortHelp=_("Move out"))
         toolBar.AddTool(ID_MEDIA_MOVE_IN, "",
-                        wx.ArtProvider.GetBitmap(wx.ART_GO_FORWARD, wx.ART_TOOLBAR, toolSize),
+                        Art.GetBitmapBundle(wx.ART_GO_FORWARD, wx.ART_TOOLBAR),  # TODO: PFS_ART
                         shortHelp=_("Move in"))
         toolBar.AddSeparator()
         toolBar.AddTool(ID_MEDIA_REMOVE, "",
-                        wx.ArtProvider.GetBitmap(wx.ART_DELETE, wx.ART_TOOLBAR, toolSize),
+                        Art.GetBitmapBundle(wx.ART_DELETE, wx.ART_TOOLBAR), # TODO: PFS_ART
                         shortHelp=_("Remove"))
         toolBar.AddSeparator()
         toolBar.AddTool(ID_PREVIEW, "",
-                        wx.ArtProvider.GetBitmap('PFS_PLAY_24'),
+                        Art.GetBitmapBundle('PFS_PLAY', wx.ART_TOOLBAR),
                         shortHelp=_("Preview"))
         toolBar.AddTool(ID_RENDER, "",
-                        wx.ArtProvider.GetBitmap('PFS_RENDER_24'),
-                        wx.ArtProvider.GetBitmap('PFS_RENDER_D_24'),
+                        Art.GetBitmapBundle('PFS_RENDER', wx.ART_TOOLBAR),
+                        Art.GetBitmapBundle('PFS_RENDER_D', wx.ART_TOOLBAR),
                         wx.ITEM_NORMAL,
                         _("Render filmstrip"),
                         _("Render filmstrip"))
@@ -572,7 +578,7 @@ class PnlMediaContainer(wx.lib.scrolledpanel.ScrolledPanel, TreeIF):
     def __init__(self, parent):
         wx.lib.scrolledpanel.ScrolledPanel.__init__(self, parent, wx.ID_ANY,
             name="pnlMediaContainer", style=wx.SUNKEN_BORDER)
-        self.SetBackgroundColour(wx.Colour(255, 255, 255))
+        self.SetBackgroundColour(wx.SystemSettings.GetColour(wx.SYS_COLOUR_LISTBOX))
 
         self.root = TreeItm()
 
@@ -706,14 +712,14 @@ class PnlMediaItem(wx.Panel):
 
     def __init__(self, parent, media):
         wx.Panel.__init__(self, parent, id=wx.ID_ANY, name='PnlMediaItem')
-        self.SetBackgroundColour(wx.Colour(255, 255, 255))
+        self.SetBackgroundColour(wx.SystemSettings.GetColour(wx.SYS_COLOUR_LISTBOX))
 
-        bmp = wx.ArtProvider.GetBitmap("PFS_ALERT_24", wx.ART_OTHER, wx.Size(24, 24))
+        bmp = Art.GetBitmapBundle("PFS_ALERT", wx.ART_BUTTON)
         if media.IsOk():
             if media.IsAudio():
-                bmp = wx.ArtProvider.GetBitmap("PFS_MUSIC_24", wx.ART_OTHER, wx.Size(24, 24))
+                bmp = Art.GetBitmapBundle("PFS_MUSIC", wx.ART_BUTTON)
             elif media.IsVideo():
-                bmp = wx.ArtProvider.GetBitmap("PFS_RENDER_24", wx.ART_OTHER, wx.Size(24, 24))
+                bmp = Art.GetBitmapBundle("PFS_RENDER", wx.ART_BUTTON)
 
         self.bmp = wx.StaticBitmap(self, wx.ID_ANY,
               bitmap=bmp)
@@ -722,9 +728,10 @@ class PnlMediaItem(wx.Panel):
               label=media.GetFilename(), name="stName")
 
         self.stInfo = wx.StaticText(self, id=wx.ID_ANY,
-              label="'00:00:00", name="stInfo")
+              label="00:00:00", name="stInfo")
 
         self.pnlOptOrientation = None
+        self.pnlOptAudio = None
         if media.IsVideo():
             self.pnlOptOrientation = PnlOptSelect(self, _("Orientation"))
             self.pnlOptOrientation.SetItemCaptionGenerator(
@@ -735,36 +742,47 @@ class PnlMediaItem(wx.Panel):
                 ctrl.Bind(wx.EVT_LEFT_DOWN, self.__OnLeftDown)
 
             self.pnlOptOrientation.Bind(EVT_VALUE_CHANGE, self.__OnOrientationChange)
-            value = media.GetProperty("orientation")
+            value = media.GetProperty(MediaOrientation.KEY())
             if value:
                 self.pnlOptOrientation.SetValue(value)
 
+            self.pnlOptAudio = PnlOptSelect(self, _("Audio"))
+            self.pnlOptAudio.SetItemCaptionGenerator(
+                lambda x: x.GetLabel())
+            self.pnlOptAudio.SetItems(list(MediaAudioLevel))
+            self.pnlOptAudio.Bind(EVT_VALUE_CHANGE, self.__OnAudioLevelChange)
+            value = media.GetProperty(MediaAudioLevel.KEY())
+            if value:
+                self.pnlOptAudio.SetValue(value)
+
         self.staticLine = wx.StaticLine(self, id=wx.ID_ANY,
               name="staticLine")
 
         szCol0Content = wx.BoxSizer(wx.VERTICAL)
-        szCol0Content.Add(self.stName, 0, border=4, flag=wx.EXPAND | wx.TOP | wx.BOTTOM)
-        szCol0Content.AddSpacer(4)
-        szCol0Content.Add(self.stInfo, 0, border=4, flag=wx.EXPAND | wx.TOP | wx.BOTTOM)
+        szCol0Content.Add(self.stName, 0, border=self.FromDIP(4), flag=wx.EXPAND | wx.TOP | wx.BOTTOM)
+        szCol0Content.AddSpacer(self.FromDIP(4))
+        szCol0Content.Add(self.stInfo, 0, border=self.FromDIP(4), flag=wx.EXPAND | wx.TOP | wx.BOTTOM)
 
         szCol0 = wx.BoxSizer(wx.HORIZONTAL)
         if media.GetParent().GetFilename() != "":
-            szCol0.AddSpacer(24)
+            szCol0.AddSpacer(self.FromDIP(24))
         szCol0.Add(self.bmp, 0, border=0, flag=wx.ALIGN_CENTER_VERTICAL)
-        szCol0.AddSpacer(4)
+        szCol0.AddSpacer(self.FromDIP(4))
         szCol0.Add(szCol0Content)
 
         szCol1 = wx.BoxSizer(wx.VERTICAL)
         if self.pnlOptOrientation:
             szCol1.Add(self.pnlOptOrientation)
+        if self.pnlOptAudio:
+            szCol1.Add(self.pnlOptAudio)
 
         szRow = wx.BoxSizer(wx.HORIZONTAL)
         szRow.Add(szCol0, 3, border=0, flag=0)
-        szRow.AddSpacer(4)
+        szRow.AddSpacer(self.FromDIP(4))
         szRow.Add(szCol1, 1, border=0, flag=0)
 
         szMain = wx.BoxSizer(wx.VERTICAL)
-        szMain.Add(szRow, 0, border=4, flag=wx.EXPAND | wx.RIGHT | wx.LEFT)
+        szMain.Add(szRow, 0, border=self.FromDIP(4), flag=wx.EXPAND | wx.RIGHT | wx.LEFT)
         szMain.Add(self.staticLine, 0, border=0, flag=wx.EXPAND)
         self.SetSizerAndFit(szMain)
 
@@ -774,6 +792,7 @@ class PnlMediaItem(wx.Panel):
         for ctrl in [self, self.stName, self.stInfo, self.pnlOptOrientation]:
             if ctrl:
                 ctrl.Bind(wx.EVT_LEFT_DOWN, self.__OnLeftDown)
+                ctrl.Bind(wx.EVT_LEFT_DCLICK, self.__OnLeftDoubleClick)
 
         font = self.stName.GetFont()
         font.SetWeight(wx.FONTWEIGHT_BOLD)
@@ -786,8 +805,18 @@ class PnlMediaItem(wx.Panel):
         if isinstance(event.GetEventObject(), wx.Control):
             event.Skip()
 
+    def __OnLeftDoubleClick(self, event):
+        evt = wx.ListEvent(wx.EVT_LIST_ITEM_ACTIVATED.typeId, self.GetId())
+        evt.SetEventObject(self)
+        self.GetEventHandler().ProcessEvent(evt)
+        if isinstance(event.GetEventObject(), wx.Control):
+            event.Skip()
+
     def __OnOrientationChange(self, event):
-        self.media.SetProperty("orientation", event.GetValue().value)
+        self.media.SetProperty(MediaOrientation.KEY(), event.GetValue().value)
+
+    def __OnAudioLevelChange(self, event):
+        self.media.SetProperty(MediaAudioLevel.KEY(), event.GetValue().value)
 
     def SetData(self, data):
         self.data = data
@@ -806,6 +835,8 @@ class PnlMediaItem(wx.Panel):
         self.stInfo.SetForegroundColour(txtCol)
         if self.pnlOptOrientation:
             self.pnlOptOrientation.SetActive(value)
+        if self.pnlOptAudio:
+            self.pnlOptAudio.SetActive(value)
 
         self.Refresh()
 
@@ -835,7 +866,7 @@ class PnlOptSelect(wx.Panel):
 
         sz = wx.BoxSizer(wx.HORIZONTAL)
         sz.Add(self.stName, flag=wx.ALIGN_CENTER_VERTICAL)
-        sz.AddSpacer(4)
+        sz.AddSpacer(self.FromDIP(4))
         sz.Add(self.stValue, flag=wx.ALIGN_CENTER_VERTICAL)
         sz.Add(self.cbOptions, flag=wx.EXPAND)
         self.SetSizeHints(wx.Size(-1, self.cbOptions.GetSize()[1]))
