@@ -7,6 +7,7 @@
 
 import wx
 
+from photofilmstrip.gui.Art import Art
 from photofilmstrip.gui.helper import ChopText
 
 
@@ -18,11 +19,11 @@ class IconLabelLink(wx.Panel):
                  label="label",
                  bmp=None,
                  descr="descr"):
-        wx.Panel.__init__(self, parent, -1, wx.DefaultPosition, (150, 150), 0, "IconLabelLink")
+        wx.Panel.__init__(self, parent, -1, wx.DefaultPosition, parent.FromDIP((150, 150)), 0, "IconLabelLink")
         self.SetBackgroundStyle(wx.BG_STYLE_CUSTOM)
 
-        self.bmpDia = wx.ArtProvider.GetBitmap('PFS_DIA')
-        self.bmpDiaSelected = wx.ArtProvider.GetBitmap('PFS_DIA_S')
+        self.bmpDia = Art.GetBitmap('PFS_DIA', size=parent.FromDIP(wx.Size(150, 138)))
+        self.bmpDiaSelected = Art.GetBitmap('PFS_DIA_S', size=parent.FromDIP(wx.Size(150, 138)))
         self.bmpThumb = bmp
         self.label = label
         self.mouseOver = False
@@ -61,17 +62,17 @@ class IconLabelLink(wx.Panel):
 
         thumbSz = self.bmpThumb.GetSize()
         thumbRect = wx.Rect(sz[0] // 2 - thumbSz[0] // 2,
-                            sz[1] // 2 - thumbSz[1] // 2 - 15,
+                            sz[1] // 2 - thumbSz[1] // 2 - dc.FromDIP(15),
                             thumbSz[0],
                             thumbSz[1])
 
         dc.DrawBitmap(self.bmpThumb, thumbRect.GetTopLeft())
-        thumbRect.Inflate(1, 1)
+        thumbRect.Inflate(dc.FromDIP(1), dc.FromDIP(1))
         dc.SetBrush(wx.TRANSPARENT_BRUSH)
         dc.DrawRectangle(thumbRect)
 
-        label, width = ChopText(dc, self.label, 138)
-        dc.DrawText(label, sz[0] // 2 - width // 2, 97)
+        label, width = ChopText(dc, self.label, dc.FromDIP(138))
+        dc.DrawText(label, sz[0] // 2 - width // 2, dc.FromDIP(97))
 
     def OnClick(self):
         raise NotImplementedError("OnClick")
