@@ -17,8 +17,8 @@ def CreateMenuItem(menu, ident, text="", bmp=None, disabledBitmap=None):
     if bmp is not None:
         item.SetBitmap(bmp)
 
-    if disabledBitmap is not None:
-        item.SetDisabledBitmap(disabledBitmap)
+#    if disabledBitmap is not None:
+#        item.SetDisabledBitmap(disabledBitmap)
 
     menu.Append(item)
 
