@@ -1,4 +1,7 @@
-# encoding: UTF-8
+# -*- coding: utf-8 -*-
+#
+# Copyright (C) 2018 Jens Goepfert
+#
 
 import logging
 import multiprocessing
@@ -175,7 +178,11 @@ class JobManager(Singleton, Destroyable):
         jcGroup.Put(jobContext)
 
         for visual in self.__visuals:
-            visual.RegisterJob(jobContext)
+            try:
+                visual.RegisterJob(jobContext)
+            except Exception:
+                self.__logger.error("RegisterJob for visual <%s> failed",  # IGNORE:W0702
+                    visual, exc_info=1)
 
     def _GetWorkLoad(self, workerCtxGroup):
         '''
@@ -265,7 +272,11 @@ class JobManager(Singleton, Destroyable):
                                 threading.currentThread().getName(), ctx.GetName())
 
         for visual in self.__visuals:
-            visual.RemoveJob(ctx)
+            try:
+                visual.RemoveJob(ctx)
+            except Exception:
+                self.__logger.error("RemoveJob for visual <%s> failed",  # IGNORE:W0702
+                    visual, exc_info=1)
 
     def Destroy(self):
         self.__logger.debug("start destroying")
@@ -278,7 +289,7 @@ class JobManager(Singleton, Destroyable):
             for worker in jcGroup.Workers():
                 self.__logger.debug("<%s> joining...", worker.getName())
                 worker.join(3)
-                if worker.isAlive():
+                if worker.is_alive():
                     self.__logger.warning("<%s> join failed", worker.getName())
                 else:
                     self.__logger.debug("<%s> joined!", worker.getName())
